# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetKnowledgeAssistantKnowledgeSourceResult',
    'AwaitableGetKnowledgeAssistantKnowledgeSourceResult',
    'get_knowledge_assistant_knowledge_source',
    'get_knowledge_assistant_knowledge_source_output',
]

@pulumi.output_type
class GetKnowledgeAssistantKnowledgeSourceResult:
    """
    A collection of values returned by getKnowledgeAssistantKnowledgeSource.
    """
    def __init__(__self__, create_time=None, description=None, display_name=None, file_table=None, files=None, id=None, index=None, knowledge_cutoff_time=None, name=None, provider_config=None, source_type=None, state=None):
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if file_table and not isinstance(file_table, dict):
            raise TypeError("Expected argument 'file_table' to be a dict")
        pulumi.set(__self__, "file_table", file_table)
        if files and not isinstance(files, dict):
            raise TypeError("Expected argument 'files' to be a dict")
        pulumi.set(__self__, "files", files)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if index and not isinstance(index, dict):
            raise TypeError("Expected argument 'index' to be a dict")
        pulumi.set(__self__, "index", index)
        if knowledge_cutoff_time and not isinstance(knowledge_cutoff_time, str):
            raise TypeError("Expected argument 'knowledge_cutoff_time' to be a str")
        pulumi.set(__self__, "knowledge_cutoff_time", knowledge_cutoff_time)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if source_type and not isinstance(source_type, str):
            raise TypeError("Expected argument 'source_type' to be a str")
        pulumi.set(__self__, "source_type", source_type)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> _builtins.str:
        """
        (string) - Timestamp when this knowledge source was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        (string) - Description of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        (string) - Human-readable display name of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="fileTable")
    def file_table(self) -> 'outputs.GetKnowledgeAssistantKnowledgeSourceFileTableResult':
        """
        (FileTableSpec)
        """
        return pulumi.get(self, "file_table")

    @_builtins.property
    @pulumi.getter
    def files(self) -> 'outputs.GetKnowledgeAssistantKnowledgeSourceFilesResult':
        """
        (FilesSpec)
        """
        return pulumi.get(self, "files")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        (string)
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def index(self) -> 'outputs.GetKnowledgeAssistantKnowledgeSourceIndexResult':
        """
        (IndexSpec)
        """
        return pulumi.get(self, "index")

    @_builtins.property
    @pulumi.getter(name="knowledgeCutoffTime")
    def knowledge_cutoff_time(self) -> _builtins.str:
        """
        (string) - Timestamp representing the cutoff before which content in this knowledge source is being ingested
        """
        return pulumi.get(self, "knowledge_cutoff_time")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Full resource name:
        knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetKnowledgeAssistantKnowledgeSourceProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> _builtins.str:
        """
        (string) - The type of the source: "index", "files", or "file_table".
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, this field is ignored
        """
        return pulumi.get(self, "source_type")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        (string) - Possible values are: `FAILED_UPDATE`, `UPDATED`, `UPDATING`
        """
        return pulumi.get(self, "state")


class AwaitableGetKnowledgeAssistantKnowledgeSourceResult(GetKnowledgeAssistantKnowledgeSourceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKnowledgeAssistantKnowledgeSourceResult(
            create_time=self.create_time,
            description=self.description,
            display_name=self.display_name,
            file_table=self.file_table,
            files=self.files,
            id=self.id,
            index=self.index,
            knowledge_cutoff_time=self.knowledge_cutoff_time,
            name=self.name,
            provider_config=self.provider_config,
            source_type=self.source_type,
            state=self.state)


def get_knowledge_assistant_knowledge_source(name: Optional[_builtins.str] = None,
                                             provider_config: Optional[Union['GetKnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'GetKnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKnowledgeAssistantKnowledgeSourceResult:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str name: Full resource name:
           knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
    :param Union['GetKnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'GetKnowledgeAssistantKnowledgeSourceProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getKnowledgeAssistantKnowledgeSource:getKnowledgeAssistantKnowledgeSource', __args__, opts=opts, typ=GetKnowledgeAssistantKnowledgeSourceResult).value

    return AwaitableGetKnowledgeAssistantKnowledgeSourceResult(
        create_time=pulumi.get(__ret__, 'create_time'),
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        file_table=pulumi.get(__ret__, 'file_table'),
        files=pulumi.get(__ret__, 'files'),
        id=pulumi.get(__ret__, 'id'),
        index=pulumi.get(__ret__, 'index'),
        knowledge_cutoff_time=pulumi.get(__ret__, 'knowledge_cutoff_time'),
        name=pulumi.get(__ret__, 'name'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        source_type=pulumi.get(__ret__, 'source_type'),
        state=pulumi.get(__ret__, 'state'))
def get_knowledge_assistant_knowledge_source_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                                    provider_config: Optional[pulumi.Input[Optional[Union['GetKnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'GetKnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']]]] = None,
                                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKnowledgeAssistantKnowledgeSourceResult]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str name: Full resource name:
           knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
    :param Union['GetKnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'GetKnowledgeAssistantKnowledgeSourceProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getKnowledgeAssistantKnowledgeSource:getKnowledgeAssistantKnowledgeSource', __args__, opts=opts, typ=GetKnowledgeAssistantKnowledgeSourceResult)
    return __ret__.apply(lambda __response__: GetKnowledgeAssistantKnowledgeSourceResult(
        create_time=pulumi.get(__response__, 'create_time'),
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        file_table=pulumi.get(__response__, 'file_table'),
        files=pulumi.get(__response__, 'files'),
        id=pulumi.get(__response__, 'id'),
        index=pulumi.get(__response__, 'index'),
        knowledge_cutoff_time=pulumi.get(__response__, 'knowledge_cutoff_time'),
        name=pulumi.get(__response__, 'name'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        source_type=pulumi.get(__response__, 'source_type'),
        state=pulumi.get(__response__, 'state')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetKnowledgeAssistantResult',
    'AwaitableGetKnowledgeAssistantResult',
    'get_knowledge_assistant',
    'get_knowledge_assistant_output',
]

@pulumi.output_type
class GetKnowledgeAssistantResult:
    """
    A collection of values returned by getKnowledgeAssistant.
    """
    def __init__(__self__, create_time=None, creator=None, description=None, display_name=None, endpoint_name=None, error_info=None, experiment_id=None, id=None, instructions=None, name=None, provider_config=None, state=None):
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if creator and not isinstance(creator, str):
            raise TypeError("Expected argument 'creator' to be a str")
        pulumi.set(__self__, "creator", creator)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if endpoint_name and not isinstance(endpoint_name, str):
            raise TypeError("Expected argument 'endpoint_name' to be a str")
        pulumi.set(__self__, "endpoint_name", endpoint_name)
        if error_info and not isinstance(error_info, str):
            raise TypeError("Expected argument 'error_info' to be a str")
        pulumi.set(__self__, "error_info", error_info)
        if experiment_id and not isinstance(experiment_id, str):
            raise TypeError("Expected argument 'experiment_id' to be a str")
        pulumi.set(__self__, "experiment_id", experiment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instructions and not isinstance(instructions, str):
            raise TypeError("Expected argument 'instructions' to be a str")
        pulumi.set(__self__, "instructions", instructions)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> _builtins.str:
        """
        (string) - Creation timestamp
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> _builtins.str:
        """
        (string) - The creator of the Knowledge Assistant
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        (string) - Description of what this agent can do (user-facing).
        Required when creating a Knowledge Assistant.
        When updating a Knowledge Assistant, optional unless included in
        update_mask
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        (string) - The display name of the Knowledge Assistant, unique at workspace level.
        Required when creating a Knowledge Assistant.
        When updating a Knowledge Assistant, optional unless included in
        update_mask
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> _builtins.str:
        """
        (string) - The name of the knowledge assistant agent endpoint
        """
        return pulumi.get(self, "endpoint_name")

    @_builtins.property
    @pulumi.getter(name="errorInfo")
    def error_info(self) -> _builtins.str:
        """
        (string) - Error details when the Knowledge Assistant is in FAILED state
        """
        return pulumi.get(self, "error_info")

    @_builtins.property
    @pulumi.getter(name="experimentId")
    def experiment_id(self) -> _builtins.str:
        """
        (string) - The MLflow experiment ID
        """
        return pulumi.get(self, "experiment_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        (string) - The universally unique identifier (UUID) of the Knowledge Assistant
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def instructions(self) -> _builtins.str:
        """
        (string) - Additional global instructions on how the agent should generate answers.
        Optional on create and update.
        When updating a Knowledge Assistant, include this field in update_mask to
        modify it
        """
        return pulumi.get(self, "instructions")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - The resource name of the Knowledge Assistant.
        Format: knowledge-assistants/{knowledge_assistant_id}
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetKnowledgeAssistantProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        (string) - State of the Knowledge Assistant. Not returned in List responses. Possible values are: `ACTIVE`, `CREATING`, `FAILED`
        """
        return pulumi.get(self, "state")


class AwaitableGetKnowledgeAssistantResult(GetKnowledgeAssistantResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKnowledgeAssistantResult(
            create_time=self.create_time,
            creator=self.creator,
            description=self.description,
            display_name=self.display_name,
            endpoint_name=self.endpoint_name,
            error_info=self.error_info,
            experiment_id=self.experiment_id,
            id=self.id,
            instructions=self.instructions,
            name=self.name,
            provider_config=self.provider_config,
            state=self.state)


def get_knowledge_assistant(name: Optional[_builtins.str] = None,
                            provider_config: Optional[Union['GetKnowledgeAssistantProviderConfigArgs', 'GetKnowledgeAssistantProviderConfigArgsDict']] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKnowledgeAssistantResult:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str name: The resource name of the Knowledge Assistant.
           Format: knowledge-assistants/{knowledge_assistant_id}
    :param Union['GetKnowledgeAssistantProviderConfigArgs', 'GetKnowledgeAssistantProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getKnowledgeAssistant:getKnowledgeAssistant', __args__, opts=opts, typ=GetKnowledgeAssistantResult).value

    return AwaitableGetKnowledgeAssistantResult(
        create_time=pulumi.get(__ret__, 'create_time'),
        creator=pulumi.get(__ret__, 'creator'),
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        endpoint_name=pulumi.get(__ret__, 'endpoint_name'),
        error_info=pulumi.get(__ret__, 'error_info'),
        experiment_id=pulumi.get(__ret__, 'experiment_id'),
        id=pulumi.get(__ret__, 'id'),
        instructions=pulumi.get(__ret__, 'instructions'),
        name=pulumi.get(__ret__, 'name'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        state=pulumi.get(__ret__, 'state'))
def get_knowledge_assistant_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                   provider_config: Optional[pulumi.Input[Optional[Union['GetKnowledgeAssistantProviderConfigArgs', 'GetKnowledgeAssistantProviderConfigArgsDict']]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKnowledgeAssistantResult]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str name: The resource name of the Knowledge Assistant.
           Format: knowledge-assistants/{knowledge_assistant_id}
    :param Union['GetKnowledgeAssistantProviderConfigArgs', 'GetKnowledgeAssistantProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getKnowledgeAssistant:getKnowledgeAssistant', __args__, opts=opts, typ=GetKnowledgeAssistantResult)
    return __ret__.apply(lambda __response__: GetKnowledgeAssistantResult(
        create_time=pulumi.get(__response__, 'create_time'),
        creator=pulumi.get(__response__, 'creator'),
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        endpoint_name=pulumi.get(__response__, 'endpoint_name'),
        error_info=pulumi.get(__response__, 'error_info'),
        experiment_id=pulumi.get(__response__, 'experiment_id'),
        id=pulumi.get(__response__, 'id'),
        instructions=pulumi.get(__response__, 'instructions'),
        name=pulumi.get(__response__, 'name'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        state=pulumi.get(__response__, 'state')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AibiDashboardEmbeddingApprovedDomainsSettingArgs', 'AibiDashboardEmbeddingApprovedDomainsSetting']

@pulumi.input_type
class AibiDashboardEmbeddingApprovedDomainsSettingArgs:
    def __init__(__self__, *,
                 aibi_dashboard_embedding_approved_domains: pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs'],
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AibiDashboardEmbeddingApprovedDomainsSetting resource.
        :param pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs'] aibi_dashboard_embedding_approved_domains: block with following attributes:
        :param pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if setting_name is not None:
            pulumi.set(__self__, "setting_name", setting_name)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']:
        """
        block with following attributes:
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @aibi_dashboard_embedding_approved_domains.setter
    def aibi_dashboard_embedding_approved_domains(self, value: pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']):
        pulumi.set(self, "aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "etag", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="settingName")
    def setting_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "setting_name")

    @setting_name.setter
    def setting_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "setting_name", value)


@pulumi.input_type
class _AibiDashboardEmbeddingApprovedDomainsSettingState:
    def __init__(__self__, *,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AibiDashboardEmbeddingApprovedDomainsSetting resources.
        :param pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs'] aibi_dashboard_embedding_approved_domains: block with following attributes:
        :param pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        if aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if setting_name is not None:
            pulumi.set(__self__, "setting_name", setting_name)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        block with following attributes:
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @aibi_dashboard_embedding_approved_domains.setter
    def aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "etag", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="settingName")
    def setting_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "setting_name")

    @setting_name.setter
    def setting_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "setting_name", value)


@pulumi.type_token("databricks:index/aibiDashboardEmbeddingApprovedDomainsSetting:AibiDashboardEmbeddingApprovedDomainsSetting")
class AibiDashboardEmbeddingApprovedDomainsSetting(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']]] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `AibiDashboardEmbeddingApprovedDomainsSetting` resource allows you to specify the list of domains allowed for  [embedding of AI/BI Dashboards](https://learn.microsoft.com/en-us/azure/databricks/dashboards/admin/#manage-dashboard-embedding) into other sites.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.AibiDashboardEmbeddingAccessPolicySetting("this", aibi_dashboard_embedding_access_policy={
            "access_policy_type": "ALLOW_APPROVED_DOMAINS",
        })
        this_aibi_dashboard_embedding_approved_domains_setting = databricks.AibiDashboardEmbeddingApprovedDomainsSetting("this", aibi_dashboard_embedding_approved_domains={
            "approved_domains": ["test.com"],
        },
        opts = pulumi.ResourceOptions(depends_on=[this]))
        ```

        ## Related Resources

        The following resources are often used in the same context:

        - AibiDashboardEmbeddingAccessPolicySetting is used to control embedding policy.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']] aibi_dashboard_embedding_approved_domains: block with following attributes:
        :param pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AibiDashboardEmbeddingApprovedDomainsSettingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `AibiDashboardEmbeddingApprovedDomainsSetting` resource allows you to specify the list of domains allowed for  [embedding of AI/BI Dashboards](https://learn.microsoft.com/en-us/azure/databricks/dashboards/admin/#manage-dashboard-embedding) into other sites.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.AibiDashboardEmbeddingAccessPolicySetting("this", aibi_dashboard_embedding_access_policy={
            "access_policy_type": "ALLOW_APPROVED_DOMAINS",
        })
        this_aibi_dashboard_embedding_approved_domains_setting = databricks.AibiDashboardEmbeddingApprovedDomainsSetting("this", aibi_dashboard_embedding_approved_domains={
            "approved_domains": ["test.com"],
        },
        opts = pulumi.ResourceOptions(depends_on=[this]))
        ```

        ## Related Resources

        The following resources are often used in the same context:

        - AibiDashboardEmbeddingAccessPolicySetting is used to control embedding policy.

        :param str resource_name: The name of the resource.
        :param AibiDashboardEmbeddingApprovedDomainsSettingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AibiDashboardEmbeddingApprovedDomainsSettingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']]] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AibiDashboardEmbeddingApprovedDomainsSettingArgs.__new__(AibiDashboardEmbeddingApprovedDomainsSettingArgs)

            if aibi_dashboard_embedding_approved_domains is None and not opts.urn:
                raise TypeError("Missing required property 'aibi_dashboard_embedding_approved_domains'")
            __props__.__dict__["aibi_dashboard_embedding_approved_domains"] = aibi_dashboard_embedding_approved_domains
            __props__.__dict__["etag"] = etag
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["setting_name"] = setting_name
        super(AibiDashboardEmbeddingApprovedDomainsSetting, __self__).__init__(
            'databricks:index/aibiDashboardEmbeddingApprovedDomainsSetting:AibiDashboardEmbeddingApprovedDomainsSetting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
            etag: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']]] = None,
            setting_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'AibiDashboardEmbeddingApprovedDomainsSetting':
        """
        Get an existing AibiDashboardEmbeddingApprovedDomainsSetting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']] aibi_dashboard_embedding_approved_domains: block with following attributes:
        :param pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AibiDashboardEmbeddingApprovedDomainsSettingState.__new__(_AibiDashboardEmbeddingApprovedDomainsSettingState)

        __props__.__dict__["aibi_dashboard_embedding_approved_domains"] = aibi_dashboard_embedding_approved_domains
        __props__.__dict__["etag"] = etag
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["setting_name"] = setting_name
        return AibiDashboardEmbeddingApprovedDomainsSetting(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> pulumi.Output['outputs.AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomains']:
        """
        block with following attributes:
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter
    def etag(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "etag")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.AibiDashboardEmbeddingApprovedDomainsSettingProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="settingName")
    def setting_name(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "setting_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DisableLegacyDbfsSettingArgs', 'DisableLegacyDbfsSetting']

@pulumi.input_type
class DisableLegacyDbfsSettingArgs:
    def __init__(__self__, *,
                 disable_legacy_dbfs: pulumi.Input['DisableLegacyDbfsSettingDisableLegacyDbfsArgs'],
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['DisableLegacyDbfsSettingProviderConfigArgs']] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DisableLegacyDbfsSetting resource.
        :param pulumi.Input['DisableLegacyDbfsSettingDisableLegacyDbfsArgs'] disable_legacy_dbfs: block with following attributes:
        :param pulumi.Input['DisableLegacyDbfsSettingProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        pulumi.set(__self__, "disable_legacy_dbfs", disable_legacy_dbfs)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if setting_name is not None:
            pulumi.set(__self__, "setting_name", setting_name)

    @_builtins.property
    @pulumi.getter(name="disableLegacyDbfs")
    def disable_legacy_dbfs(self) -> pulumi.Input['DisableLegacyDbfsSettingDisableLegacyDbfsArgs']:
        """
        block with following attributes:
        """
        return pulumi.get(self, "disable_legacy_dbfs")

    @disable_legacy_dbfs.setter
    def disable_legacy_dbfs(self, value: pulumi.Input['DisableLegacyDbfsSettingDisableLegacyDbfsArgs']):
        pulumi.set(self, "disable_legacy_dbfs", value)

    @_builtins.property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "etag", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DisableLegacyDbfsSettingProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DisableLegacyDbfsSettingProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="settingName")
    def setting_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "setting_name")

    @setting_name.setter
    def setting_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "setting_name", value)


@pulumi.input_type
class _DisableLegacyDbfsSettingState:
    def __init__(__self__, *,
                 disable_legacy_dbfs: Optional[pulumi.Input['DisableLegacyDbfsSettingDisableLegacyDbfsArgs']] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['DisableLegacyDbfsSettingProviderConfigArgs']] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DisableLegacyDbfsSetting resources.
        :param pulumi.Input['DisableLegacyDbfsSettingDisableLegacyDbfsArgs'] disable_legacy_dbfs: block with following attributes:
        :param pulumi.Input['DisableLegacyDbfsSettingProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        if disable_legacy_dbfs is not None:
            pulumi.set(__self__, "disable_legacy_dbfs", disable_legacy_dbfs)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if setting_name is not None:
            pulumi.set(__self__, "setting_name", setting_name)

    @_builtins.property
    @pulumi.getter(name="disableLegacyDbfs")
    def disable_legacy_dbfs(self) -> Optional[pulumi.Input['DisableLegacyDbfsSettingDisableLegacyDbfsArgs']]:
        """
        block with following attributes:
        """
        return pulumi.get(self, "disable_legacy_dbfs")

    @disable_legacy_dbfs.setter
    def disable_legacy_dbfs(self, value: Optional[pulumi.Input['DisableLegacyDbfsSettingDisableLegacyDbfsArgs']]):
        pulumi.set(self, "disable_legacy_dbfs", value)

    @_builtins.property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "etag", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DisableLegacyDbfsSettingProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DisableLegacyDbfsSettingProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="settingName")
    def setting_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "setting_name")

    @setting_name.setter
    def setting_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "setting_name", value)


@pulumi.type_token("databricks:index/disableLegacyDbfsSetting:DisableLegacyDbfsSetting")
class DisableLegacyDbfsSetting(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disable_legacy_dbfs: Optional[pulumi.Input[Union['DisableLegacyDbfsSettingDisableLegacyDbfsArgs', 'DisableLegacyDbfsSettingDisableLegacyDbfsArgsDict']]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['DisableLegacyDbfsSettingProviderConfigArgs', 'DisableLegacyDbfsSettingProviderConfigArgsDict']]] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `DisableLegacyDbfsSetting` resource allows you to disable legacy DBFS.

        > This resource can only be used with a workspace-level provider!

        Disabling legacy DBFS has the following implications:

        1. Access to DBFS root and DBFS mounts is disallowed (as well as the creation of new mounts).
        2. Disables Databricks Runtime versions prior to 13.3LTS.

        When the setting is off, all DBFS functionality is enabled and no restrictions are imposed on Databricks Runtime versions. This setting can take up to 20 minutes to take effect and requires a manual restart of all-purpose compute clusters and SQL warehouses.

        Refer to official docs for more details:

        - [Azure](https://learn.microsoft.com/azure/databricks/dbfs/disable-dbfs-root-mounts)
        - [AWS](https://docs.databricks.com/aws/dbfs/disable-dbfs-root-mounts)
        - [GCP](https://docs.gcp.databricks.com/dbfs/disable-dbfs-root-mounts)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DisableLegacyDbfsSetting("this", disable_legacy_dbfs={
            "value": True,
        })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['DisableLegacyDbfsSettingDisableLegacyDbfsArgs', 'DisableLegacyDbfsSettingDisableLegacyDbfsArgsDict']] disable_legacy_dbfs: block with following attributes:
        :param pulumi.Input[Union['DisableLegacyDbfsSettingProviderConfigArgs', 'DisableLegacyDbfsSettingProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DisableLegacyDbfsSettingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `DisableLegacyDbfsSetting` resource allows you to disable legacy DBFS.

        > This resource can only be used with a workspace-level provider!

        Disabling legacy DBFS has the following implications:

        1. Access to DBFS root and DBFS mounts is disallowed (as well as the creation of new mounts).
        2. Disables Databricks Runtime versions prior to 13.3LTS.

        When the setting is off, all DBFS functionality is enabled and no restrictions are imposed on Databricks Runtime versions. This setting can take up to 20 minutes to take effect and requires a manual restart of all-purpose compute clusters and SQL warehouses.

        Refer to official docs for more details:

        - [Azure](https://learn.microsoft.com/azure/databricks/dbfs/disable-dbfs-root-mounts)
        - [AWS](https://docs.databricks.com/aws/dbfs/disable-dbfs-root-mounts)
        - [GCP](https://docs.gcp.databricks.com/dbfs/disable-dbfs-root-mounts)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DisableLegacyDbfsSetting("this", disable_legacy_dbfs={
            "value": True,
        })
        ```

        :param str resource_name: The name of the resource.
        :param DisableLegacyDbfsSettingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DisableLegacyDbfsSettingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disable_legacy_dbfs: Optional[pulumi.Input[Union['DisableLegacyDbfsSettingDisableLegacyDbfsArgs', 'DisableLegacyDbfsSettingDisableLegacyDbfsArgsDict']]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['DisableLegacyDbfsSettingProviderConfigArgs', 'DisableLegacyDbfsSettingProviderConfigArgsDict']]] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DisableLegacyDbfsSettingArgs.__new__(DisableLegacyDbfsSettingArgs)

            if disable_legacy_dbfs is None and not opts.urn:
                raise TypeError("Missing required property 'disable_legacy_dbfs'")
            __props__.__dict__["disable_legacy_dbfs"] = disable_legacy_dbfs
            __props__.__dict__["etag"] = etag
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["setting_name"] = setting_name
        super(DisableLegacyDbfsSetting, __self__).__init__(
            'databricks:index/disableLegacyDbfsSetting:DisableLegacyDbfsSetting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            disable_legacy_dbfs: Optional[pulumi.Input[Union['DisableLegacyDbfsSettingDisableLegacyDbfsArgs', 'DisableLegacyDbfsSettingDisableLegacyDbfsArgsDict']]] = None,
            etag: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['DisableLegacyDbfsSettingProviderConfigArgs', 'DisableLegacyDbfsSettingProviderConfigArgsDict']]] = None,
            setting_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'DisableLegacyDbfsSetting':
        """
        Get an existing DisableLegacyDbfsSetting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['DisableLegacyDbfsSettingDisableLegacyDbfsArgs', 'DisableLegacyDbfsSettingDisableLegacyDbfsArgsDict']] disable_legacy_dbfs: block with following attributes:
        :param pulumi.Input[Union['DisableLegacyDbfsSettingProviderConfigArgs', 'DisableLegacyDbfsSettingProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DisableLegacyDbfsSettingState.__new__(_DisableLegacyDbfsSettingState)

        __props__.__dict__["disable_legacy_dbfs"] = disable_legacy_dbfs
        __props__.__dict__["etag"] = etag
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["setting_name"] = setting_name
        return DisableLegacyDbfsSetting(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="disableLegacyDbfs")
    def disable_legacy_dbfs(self) -> pulumi.Output['outputs.DisableLegacyDbfsSettingDisableLegacyDbfs']:
        """
        block with following attributes:
        """
        return pulumi.get(self, "disable_legacy_dbfs")

    @_builtins.property
    @pulumi.getter
    def etag(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "etag")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.DisableLegacyDbfsSettingProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="settingName")
    def setting_name(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "setting_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KnowledgeAssistantArgs', 'KnowledgeAssistant']

@pulumi.input_type
class KnowledgeAssistantArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[_builtins.str],
                 display_name: pulumi.Input[_builtins.str],
                 instructions: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['KnowledgeAssistantProviderConfigArgs']] = None):
        """
        The set of arguments for constructing a KnowledgeAssistant resource.
        :param pulumi.Input[_builtins.str] description: Description of what this agent can do (user-facing).
               Required when creating a Knowledge Assistant.
               When updating a Knowledge Assistant, optional unless included in
               update_mask
        :param pulumi.Input[_builtins.str] display_name: The display name of the Knowledge Assistant, unique at workspace level.
               Required when creating a Knowledge Assistant.
               When updating a Knowledge Assistant, optional unless included in
               update_mask
        :param pulumi.Input[_builtins.str] instructions: Additional global instructions on how the agent should generate answers.
               Optional on create and update.
               When updating a Knowledge Assistant, include this field in update_mask to
               modify it
        :param pulumi.Input['KnowledgeAssistantProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        if instructions is not None:
            pulumi.set(__self__, "instructions", instructions)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Input[_builtins.str]:
        """
        Description of what this agent can do (user-facing).
        Required when creating a Knowledge Assistant.
        When updating a Knowledge Assistant, optional unless included in
        update_mask
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The display name of the Knowledge Assistant, unique at workspace level.
        Required when creating a Knowledge Assistant.
        When updating a Knowledge Assistant, optional unless included in
        update_mask
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def instructions(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional global instructions on how the agent should generate answers.
        Optional on create and update.
        When updating a Knowledge Assistant, include this field in update_mask to
        modify it
        """
        return pulumi.get(self, "instructions")

    @instructions.setter
    def instructions(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "instructions", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['KnowledgeAssistantProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['KnowledgeAssistantProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.input_type
class _KnowledgeAssistantState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 creator: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint_name: Optional[pulumi.Input[_builtins.str]] = None,
                 error_info: Optional[pulumi.Input[_builtins.str]] = None,
                 experiment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 instructions: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['KnowledgeAssistantProviderConfigArgs']] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering KnowledgeAssistant resources.
        :param pulumi.Input[_builtins.str] create_time: (string) - Creation timestamp
        :param pulumi.Input[_builtins.str] creator: (string) - The creator of the Knowledge Assistant
        :param pulumi.Input[_builtins.str] description: Description of what this agent can do (user-facing).
               Required when creating a Knowledge Assistant.
               When updating a Knowledge Assistant, optional unless included in
               update_mask
        :param pulumi.Input[_builtins.str] display_name: The display name of the Knowledge Assistant, unique at workspace level.
               Required when creating a Knowledge Assistant.
               When updating a Knowledge Assistant, optional unless included in
               update_mask
        :param pulumi.Input[_builtins.str] endpoint_name: (string) - The name of the knowledge assistant agent endpoint
        :param pulumi.Input[_builtins.str] error_info: (string) - Error details when the Knowledge Assistant is in FAILED state
        :param pulumi.Input[_builtins.str] experiment_id: (string) - The MLflow experiment ID
        :param pulumi.Input[_builtins.str] instructions: Additional global instructions on how the agent should generate answers.
               Optional on create and update.
               When updating a Knowledge Assistant, include this field in update_mask to
               modify it
        :param pulumi.Input[_builtins.str] name: (string) - The resource name of the Knowledge Assistant.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input['KnowledgeAssistantProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] state: (string) - State of the Knowledge Assistant. Not returned in List responses. Possible values are: `ACTIVE`, `CREATING`, `FAILED`
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if creator is not None:
            pulumi.set(__self__, "creator", creator)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if endpoint_name is not None:
            pulumi.set(__self__, "endpoint_name", endpoint_name)
        if error_info is not None:
            pulumi.set(__self__, "error_info", error_info)
        if experiment_id is not None:
            pulumi.set(__self__, "experiment_id", experiment_id)
        if instructions is not None:
            pulumi.set(__self__, "instructions", instructions)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Creation timestamp
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def creator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The creator of the Knowledge Assistant
        """
        return pulumi.get(self, "creator")

    @creator.setter
    def creator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of what this agent can do (user-facing).
        Required when creating a Knowledge Assistant.
        When updating a Knowledge Assistant, optional unless included in
        update_mask
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of the Knowledge Assistant, unique at workspace level.
        Required when creating a Knowledge Assistant.
        When updating a Knowledge Assistant, optional unless included in
        update_mask
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The name of the knowledge assistant agent endpoint
        """
        return pulumi.get(self, "endpoint_name")

    @endpoint_name.setter
    def endpoint_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_name", value)

    @_builtins.property
    @pulumi.getter(name="errorInfo")
    def error_info(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Error details when the Knowledge Assistant is in FAILED state
        """
        return pulumi.get(self, "error_info")

    @error_info.setter
    def error_info(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "error_info", value)

    @_builtins.property
    @pulumi.getter(name="experimentId")
    def experiment_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The MLflow experiment ID
        """
        return pulumi.get(self, "experiment_id")

    @experiment_id.setter
    def experiment_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "experiment_id", value)

    @_builtins.property
    @pulumi.getter
    def instructions(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional global instructions on how the agent should generate answers.
        Optional on create and update.
        When updating a Knowledge Assistant, include this field in update_mask to
        modify it
        """
        return pulumi.get(self, "instructions")

    @instructions.setter
    def instructions(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "instructions", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The resource name of the Knowledge Assistant.
        Format: knowledge-assistants/{knowledge_assistant_id}
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['KnowledgeAssistantProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['KnowledgeAssistantProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - State of the Knowledge Assistant. Not returned in List responses. Possible values are: `ACTIVE`, `CREATING`, `FAILED`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)


@pulumi.type_token("databricks:index/knowledgeAssistant:KnowledgeAssistant")
class KnowledgeAssistant(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 instructions: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['KnowledgeAssistantProviderConfigArgs', 'KnowledgeAssistantProviderConfigArgsDict']]] = None,
                 __props__=None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of what this agent can do (user-facing).
               Required when creating a Knowledge Assistant.
               When updating a Knowledge Assistant, optional unless included in
               update_mask
        :param pulumi.Input[_builtins.str] display_name: The display name of the Knowledge Assistant, unique at workspace level.
               Required when creating a Knowledge Assistant.
               When updating a Knowledge Assistant, optional unless included in
               update_mask
        :param pulumi.Input[_builtins.str] instructions: Additional global instructions on how the agent should generate answers.
               Optional on create and update.
               When updating a Knowledge Assistant, include this field in update_mask to
               modify it
        :param pulumi.Input[Union['KnowledgeAssistantProviderConfigArgs', 'KnowledgeAssistantProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KnowledgeAssistantArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        :param str resource_name: The name of the resource.
        :param KnowledgeAssistantArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KnowledgeAssistantArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 instructions: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['KnowledgeAssistantProviderConfigArgs', 'KnowledgeAssistantProviderConfigArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KnowledgeAssistantArgs.__new__(KnowledgeAssistantArgs)

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["instructions"] = instructions
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["create_time"] = None
            __props__.__dict__["creator"] = None
            __props__.__dict__["endpoint_name"] = None
            __props__.__dict__["error_info"] = None
            __props__.__dict__["experiment_id"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["state"] = None
        super(KnowledgeAssistant, __self__).__init__(
            'databricks:index/knowledgeAssistant:KnowledgeAssistant',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            creator: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint_name: Optional[pulumi.Input[_builtins.str]] = None,
            error_info: Optional[pulumi.Input[_builtins.str]] = None,
            experiment_id: Optional[pulumi.Input[_builtins.str]] = None,
            instructions: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['KnowledgeAssistantProviderConfigArgs', 'KnowledgeAssistantProviderConfigArgsDict']]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None) -> 'KnowledgeAssistant':
        """
        Get an existing KnowledgeAssistant resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: (string) - Creation timestamp
        :param pulumi.Input[_builtins.str] creator: (string) - The creator of the Knowledge Assistant
        :param pulumi.Input[_builtins.str] description: Description of what this agent can do (user-facing).
               Required when creating a Knowledge Assistant.
               When updating a Knowledge Assistant, optional unless included in
               update_mask
        :param pulumi.Input[_builtins.str] display_name: The display name of the Knowledge Assistant, unique at workspace level.
               Required when creating a Knowledge Assistant.
               When updating a Knowledge Assistant, optional unless included in
               update_mask
        :param pulumi.Input[_builtins.str] endpoint_name: (string) - The name of the knowledge assistant agent endpoint
        :param pulumi.Input[_builtins.str] error_info: (string) - Error details when the Knowledge Assistant is in FAILED state
        :param pulumi.Input[_builtins.str] experiment_id: (string) - The MLflow experiment ID
        :param pulumi.Input[_builtins.str] instructions: Additional global instructions on how the agent should generate answers.
               Optional on create and update.
               When updating a Knowledge Assistant, include this field in update_mask to
               modify it
        :param pulumi.Input[_builtins.str] name: (string) - The resource name of the Knowledge Assistant.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input[Union['KnowledgeAssistantProviderConfigArgs', 'KnowledgeAssistantProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] state: (string) - State of the Knowledge Assistant. Not returned in List responses. Possible values are: `ACTIVE`, `CREATING`, `FAILED`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KnowledgeAssistantState.__new__(_KnowledgeAssistantState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["creator"] = creator
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["endpoint_name"] = endpoint_name
        __props__.__dict__["error_info"] = error_info
        __props__.__dict__["experiment_id"] = experiment_id
        __props__.__dict__["instructions"] = instructions
        __props__.__dict__["name"] = name
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["state"] = state
        return KnowledgeAssistant(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Creation timestamp
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The creator of the Knowledge Assistant
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Description of what this agent can do (user-facing).
        Required when creating a Knowledge Assistant.
        When updating a Knowledge Assistant, optional unless included in
        update_mask
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name of the Knowledge Assistant, unique at workspace level.
        Required when creating a Knowledge Assistant.
        When updating a Knowledge Assistant, optional unless included in
        update_mask
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The name of the knowledge assistant agent endpoint
        """
        return pulumi.get(self, "endpoint_name")

    @_builtins.property
    @pulumi.getter(name="errorInfo")
    def error_info(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Error details when the Knowledge Assistant is in FAILED state
        """
        return pulumi.get(self, "error_info")

    @_builtins.property
    @pulumi.getter(name="experimentId")
    def experiment_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The MLflow experiment ID
        """
        return pulumi.get(self, "experiment_id")

    @_builtins.property
    @pulumi.getter
    def instructions(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Additional global instructions on how the agent should generate answers.
        Optional on create and update.
        When updating a Knowledge Assistant, include this field in update_mask to
        modify it
        """
        return pulumi.get(self, "instructions")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The resource name of the Knowledge Assistant.
        Format: knowledge-assistants/{knowledge_assistant_id}
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.KnowledgeAssistantProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - State of the Knowledge Assistant. Not returned in List responses. Possible values are: `ACTIVE`, `CREATING`, `FAILED`
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AccountSettingUserPreferenceV2Args', 'AccountSettingUserPreferenceV2']

@pulumi.input_type
class AccountSettingUserPreferenceV2Args:
    def __init__(__self__, *,
                 boolean_val: Optional[pulumi.Input['AccountSettingUserPreferenceV2BooleanValArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 string_val: Optional[pulumi.Input['AccountSettingUserPreferenceV2StringValArgs']] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AccountSettingUserPreferenceV2 resource.
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input[_builtins.str] user_id: User ID of the user
        """
        if boolean_val is not None:
            pulumi.set(__self__, "boolean_val", boolean_val)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if string_val is not None:
            pulumi.set(__self__, "string_val", string_val)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> Optional[pulumi.Input['AccountSettingUserPreferenceV2BooleanValArgs']]:
        return pulumi.get(self, "boolean_val")

    @boolean_val.setter
    def boolean_val(self, value: Optional[pulumi.Input['AccountSettingUserPreferenceV2BooleanValArgs']]):
        pulumi.set(self, "boolean_val", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the setting
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> Optional[pulumi.Input['AccountSettingUserPreferenceV2StringValArgs']]:
        return pulumi.get(self, "string_val")

    @string_val.setter
    def string_val(self, value: Optional[pulumi.Input['AccountSettingUserPreferenceV2StringValArgs']]):
        pulumi.set(self, "string_val", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User ID of the user
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _AccountSettingUserPreferenceV2State:
    def __init__(__self__, *,
                 boolean_val: Optional[pulumi.Input['AccountSettingUserPreferenceV2BooleanValArgs']] = None,
                 effective_boolean_val: Optional[pulumi.Input['AccountSettingUserPreferenceV2EffectiveBooleanValArgs']] = None,
                 effective_string_val: Optional[pulumi.Input['AccountSettingUserPreferenceV2EffectiveStringValArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 string_val: Optional[pulumi.Input['AccountSettingUserPreferenceV2StringValArgs']] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AccountSettingUserPreferenceV2 resources.
        :param pulumi.Input['AccountSettingUserPreferenceV2EffectiveBooleanValArgs'] effective_boolean_val: (BooleanMessage)
        :param pulumi.Input['AccountSettingUserPreferenceV2EffectiveStringValArgs'] effective_string_val: (StringMessage)
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input[_builtins.str] user_id: User ID of the user
        """
        if boolean_val is not None:
            pulumi.set(__self__, "boolean_val", boolean_val)
        if effective_boolean_val is not None:
            pulumi.set(__self__, "effective_boolean_val", effective_boolean_val)
        if effective_string_val is not None:
            pulumi.set(__self__, "effective_string_val", effective_string_val)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if string_val is not None:
            pulumi.set(__self__, "string_val", string_val)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> Optional[pulumi.Input['AccountSettingUserPreferenceV2BooleanValArgs']]:
        return pulumi.get(self, "boolean_val")

    @boolean_val.setter
    def boolean_val(self, value: Optional[pulumi.Input['AccountSettingUserPreferenceV2BooleanValArgs']]):
        pulumi.set(self, "boolean_val", value)

    @_builtins.property
    @pulumi.getter(name="effectiveBooleanVal")
    def effective_boolean_val(self) -> Optional[pulumi.Input['AccountSettingUserPreferenceV2EffectiveBooleanValArgs']]:
        """
        (BooleanMessage)
        """
        return pulumi.get(self, "effective_boolean_val")

    @effective_boolean_val.setter
    def effective_boolean_val(self, value: Optional[pulumi.Input['AccountSettingUserPreferenceV2EffectiveBooleanValArgs']]):
        pulumi.set(self, "effective_boolean_val", value)

    @_builtins.property
    @pulumi.getter(name="effectiveStringVal")
    def effective_string_val(self) -> Optional[pulumi.Input['AccountSettingUserPreferenceV2EffectiveStringValArgs']]:
        """
        (StringMessage)
        """
        return pulumi.get(self, "effective_string_val")

    @effective_string_val.setter
    def effective_string_val(self, value: Optional[pulumi.Input['AccountSettingUserPreferenceV2EffectiveStringValArgs']]):
        pulumi.set(self, "effective_string_val", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the setting
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> Optional[pulumi.Input['AccountSettingUserPreferenceV2StringValArgs']]:
        return pulumi.get(self, "string_val")

    @string_val.setter
    def string_val(self, value: Optional[pulumi.Input['AccountSettingUserPreferenceV2StringValArgs']]):
        pulumi.set(self, "string_val", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User ID of the user
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("databricks:index/accountSettingUserPreferenceV2:AccountSettingUserPreferenceV2")
class AccountSettingUserPreferenceV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 boolean_val: Optional[pulumi.Input[Union['AccountSettingUserPreferenceV2BooleanValArgs', 'AccountSettingUserPreferenceV2BooleanValArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 string_val: Optional[pulumi.Input[Union['AccountSettingUserPreferenceV2StringValArgs', 'AccountSettingUserPreferenceV2StringValArgsDict']]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        User preference is a configurable value that determines how a feature or behavior works for a specific user within the Databricks platform.

        See user settings-metadata API for list of user preferences that can be modified using this resource.

        ## Example Usage

        Setting an account user preference:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        theme_setting = databricks.index.AccountUserSettingV2("theme_setting",
            user_id=<user-id>,
            name=enableDarkMode,
            string_val={
                value: dark,
            })
        ```

        Setting a boolean user preference:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        enable_line_numbers = databricks.index.AccountUserSettingV2("enable_line_numbers",
            user_id=<user-id>,
            name=enableLineNumbers,
            boolean_val={
                value: True,
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input[_builtins.str] user_id: User ID of the user
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AccountSettingUserPreferenceV2Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        User preference is a configurable value that determines how a feature or behavior works for a specific user within the Databricks platform.

        See user settings-metadata API for list of user preferences that can be modified using this resource.

        ## Example Usage

        Setting an account user preference:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        theme_setting = databricks.index.AccountUserSettingV2("theme_setting",
            user_id=<user-id>,
            name=enableDarkMode,
            string_val={
                value: dark,
            })
        ```

        Setting a boolean user preference:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        enable_line_numbers = databricks.index.AccountUserSettingV2("enable_line_numbers",
            user_id=<user-id>,
            name=enableLineNumbers,
            boolean_val={
                value: True,
            })
        ```

        :param str resource_name: The name of the resource.
        :param AccountSettingUserPreferenceV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountSettingUserPreferenceV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 boolean_val: Optional[pulumi.Input[Union['AccountSettingUserPreferenceV2BooleanValArgs', 'AccountSettingUserPreferenceV2BooleanValArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 string_val: Optional[pulumi.Input[Union['AccountSettingUserPreferenceV2StringValArgs', 'AccountSettingUserPreferenceV2StringValArgsDict']]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountSettingUserPreferenceV2Args.__new__(AccountSettingUserPreferenceV2Args)

            __props__.__dict__["boolean_val"] = boolean_val
            __props__.__dict__["name"] = name
            __props__.__dict__["string_val"] = string_val
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["effective_boolean_val"] = None
            __props__.__dict__["effective_string_val"] = None
        super(AccountSettingUserPreferenceV2, __self__).__init__(
            'databricks:index/accountSettingUserPreferenceV2:AccountSettingUserPreferenceV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            boolean_val: Optional[pulumi.Input[Union['AccountSettingUserPreferenceV2BooleanValArgs', 'AccountSettingUserPreferenceV2BooleanValArgsDict']]] = None,
            effective_boolean_val: Optional[pulumi.Input[Union['AccountSettingUserPreferenceV2EffectiveBooleanValArgs', 'AccountSettingUserPreferenceV2EffectiveBooleanValArgsDict']]] = None,
            effective_string_val: Optional[pulumi.Input[Union['AccountSettingUserPreferenceV2EffectiveStringValArgs', 'AccountSettingUserPreferenceV2EffectiveStringValArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            string_val: Optional[pulumi.Input[Union['AccountSettingUserPreferenceV2StringValArgs', 'AccountSettingUserPreferenceV2StringValArgsDict']]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'AccountSettingUserPreferenceV2':
        """
        Get an existing AccountSettingUserPreferenceV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AccountSettingUserPreferenceV2EffectiveBooleanValArgs', 'AccountSettingUserPreferenceV2EffectiveBooleanValArgsDict']] effective_boolean_val: (BooleanMessage)
        :param pulumi.Input[Union['AccountSettingUserPreferenceV2EffectiveStringValArgs', 'AccountSettingUserPreferenceV2EffectiveStringValArgsDict']] effective_string_val: (StringMessage)
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input[_builtins.str] user_id: User ID of the user
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountSettingUserPreferenceV2State.__new__(_AccountSettingUserPreferenceV2State)

        __props__.__dict__["boolean_val"] = boolean_val
        __props__.__dict__["effective_boolean_val"] = effective_boolean_val
        __props__.__dict__["effective_string_val"] = effective_string_val
        __props__.__dict__["name"] = name
        __props__.__dict__["string_val"] = string_val
        __props__.__dict__["user_id"] = user_id
        return AccountSettingUserPreferenceV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> pulumi.Output[Optional['outputs.AccountSettingUserPreferenceV2BooleanVal']]:
        return pulumi.get(self, "boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveBooleanVal")
    def effective_boolean_val(self) -> pulumi.Output['outputs.AccountSettingUserPreferenceV2EffectiveBooleanVal']:
        """
        (BooleanMessage)
        """
        return pulumi.get(self, "effective_boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveStringVal")
    def effective_string_val(self) -> pulumi.Output['outputs.AccountSettingUserPreferenceV2EffectiveStringVal']:
        """
        (StringMessage)
        """
        return pulumi.get(self, "effective_string_val")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the setting
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> pulumi.Output[Optional['outputs.AccountSettingUserPreferenceV2StringVal']]:
        return pulumi.get(self, "string_val")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        User ID of the user
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PostgresBranchArgs', 'PostgresBranch']

@pulumi.input_type
class PostgresBranchArgs:
    def __init__(__self__, *,
                 branch_id: pulumi.Input[_builtins.str],
                 parent: pulumi.Input[_builtins.str],
                 provider_config: Optional[pulumi.Input['PostgresBranchProviderConfigArgs']] = None,
                 spec: Optional[pulumi.Input['PostgresBranchSpecArgs']] = None):
        """
        The set of arguments for constructing a PostgresBranch resource.
        :param pulumi.Input[_builtins.str] branch_id: The ID to use for the Branch. This becomes the final component of the branch's resource name.
               The ID is required and must be 1-63 characters long, start with a lowercase letter, and contain only lowercase letters, numbers, and hyphens.
               For example, `development` becomes `projects/my-app/branches/development`
        :param pulumi.Input[_builtins.str] parent: The project containing this branch (API resource hierarchy).
               Format: projects/{project_id}
               
               Note: This field indicates where the branch exists in the resource hierarchy.
               For point-in-time branching from another branch, see `status.source_branch`
        :param pulumi.Input['PostgresBranchProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input['PostgresBranchSpecArgs'] spec: The spec contains the branch configuration
        """
        pulumi.set(__self__, "branch_id", branch_id)
        pulumi.set(__self__, "parent", parent)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)

    @_builtins.property
    @pulumi.getter(name="branchId")
    def branch_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID to use for the Branch. This becomes the final component of the branch's resource name.
        The ID is required and must be 1-63 characters long, start with a lowercase letter, and contain only lowercase letters, numbers, and hyphens.
        For example, `development` becomes `projects/my-app/branches/development`
        """
        return pulumi.get(self, "branch_id")

    @branch_id.setter
    def branch_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "branch_id", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Input[_builtins.str]:
        """
        The project containing this branch (API resource hierarchy).
        Format: projects/{project_id}

        Note: This field indicates where the branch exists in the resource hierarchy.
        For point-in-time branching from another branch, see `status.source_branch`
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['PostgresBranchProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['PostgresBranchProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['PostgresBranchSpecArgs']]:
        """
        The spec contains the branch configuration
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['PostgresBranchSpecArgs']]):
        pulumi.set(self, "spec", value)


@pulumi.input_type
class _PostgresBranchState:
    def __init__(__self__, *,
                 branch_id: Optional[pulumi.Input[_builtins.str]] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['PostgresBranchProviderConfigArgs']] = None,
                 spec: Optional[pulumi.Input['PostgresBranchSpecArgs']] = None,
                 status: Optional[pulumi.Input['PostgresBranchStatusArgs']] = None,
                 uid: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PostgresBranch resources.
        :param pulumi.Input[_builtins.str] branch_id: The ID to use for the Branch. This becomes the final component of the branch's resource name.
               The ID is required and must be 1-63 characters long, start with a lowercase letter, and contain only lowercase letters, numbers, and hyphens.
               For example, `development` becomes `projects/my-app/branches/development`
        :param pulumi.Input[_builtins.str] create_time: (string) - A timestamp indicating when the branch was created
        :param pulumi.Input[_builtins.str] name: (string) - Output only. The full resource path of the branch.
               Format: projects/{project_id}/branches/{branch_id}
        :param pulumi.Input[_builtins.str] parent: The project containing this branch (API resource hierarchy).
               Format: projects/{project_id}
               
               Note: This field indicates where the branch exists in the resource hierarchy.
               For point-in-time branching from another branch, see `status.source_branch`
        :param pulumi.Input['PostgresBranchProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input['PostgresBranchSpecArgs'] spec: The spec contains the branch configuration
        :param pulumi.Input['PostgresBranchStatusArgs'] status: (BranchStatus) - The current status of a Branch
        :param pulumi.Input[_builtins.str] uid: (string) - System-generated unique ID for the branch
        :param pulumi.Input[_builtins.str] update_time: (string) - A timestamp indicating when the branch was last updated
        """
        if branch_id is not None:
            pulumi.set(__self__, "branch_id", branch_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @_builtins.property
    @pulumi.getter(name="branchId")
    def branch_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID to use for the Branch. This becomes the final component of the branch's resource name.
        The ID is required and must be 1-63 characters long, start with a lowercase letter, and contain only lowercase letters, numbers, and hyphens.
        For example, `development` becomes `projects/my-app/branches/development`
        """
        return pulumi.get(self, "branch_id")

    @branch_id.setter
    def branch_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "branch_id", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - A timestamp indicating when the branch was created
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Output only. The full resource path of the branch.
        Format: projects/{project_id}/branches/{branch_id}
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project containing this branch (API resource hierarchy).
        Format: projects/{project_id}

        Note: This field indicates where the branch exists in the resource hierarchy.
        For point-in-time branching from another branch, see `status.source_branch`
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['PostgresBranchProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['PostgresBranchProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['PostgresBranchSpecArgs']]:
        """
        The spec contains the branch configuration
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['PostgresBranchSpecArgs']]):
        pulumi.set(self, "spec", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['PostgresBranchStatusArgs']]:
        """
        (BranchStatus) - The current status of a Branch
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['PostgresBranchStatusArgs']]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - System-generated unique ID for the branch
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "uid", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - A timestamp indicating when the branch was last updated
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("databricks:index/postgresBranch:PostgresBranch")
class PostgresBranch(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branch_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['PostgresBranchProviderConfigArgs', 'PostgresBranchProviderConfigArgsDict']]] = None,
                 spec: Optional[pulumi.Input[Union['PostgresBranchSpecArgs', 'PostgresBranchSpecArgsDict']]] = None,
                 __props__=None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Example Usage

        ### Basic Branch Creation

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.PostgresProject("this",
            project_id="my-project",
            spec={
                "pg_version": 17,
                "display_name": "My Project",
            })
        dev = databricks.PostgresBranch("dev",
            branch_id="dev-branch",
            parent=this.name,
            spec={
                "no_expiry": True,
            })
        ```

        ### Protected Branch

        ```python
        import pulumi
        import pulumi_databricks as databricks

        production = databricks.PostgresBranch("production",
            branch_id="production",
            parent=this["name"],
            spec={
                "is_protected": True,
                "no_expiry": True,
            })
        ```

        ### Branch with Expiration (TTL)

        ```python
        import pulumi
        import pulumi_databricks as databricks

        temporary = databricks.PostgresBranch("temporary",
            branch_id="temp-feature-test",
            parent=this["name"],
            spec={
                "ttl": "604800s",
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] branch_id: The ID to use for the Branch. This becomes the final component of the branch's resource name.
               The ID is required and must be 1-63 characters long, start with a lowercase letter, and contain only lowercase letters, numbers, and hyphens.
               For example, `development` becomes `projects/my-app/branches/development`
        :param pulumi.Input[_builtins.str] parent: The project containing this branch (API resource hierarchy).
               Format: projects/{project_id}
               
               Note: This field indicates where the branch exists in the resource hierarchy.
               For point-in-time branching from another branch, see `status.source_branch`
        :param pulumi.Input[Union['PostgresBranchProviderConfigArgs', 'PostgresBranchProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Union['PostgresBranchSpecArgs', 'PostgresBranchSpecArgsDict']] spec: The spec contains the branch configuration
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PostgresBranchArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Example Usage

        ### Basic Branch Creation

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.PostgresProject("this",
            project_id="my-project",
            spec={
                "pg_version": 17,
                "display_name": "My Project",
            })
        dev = databricks.PostgresBranch("dev",
            branch_id="dev-branch",
            parent=this.name,
            spec={
                "no_expiry": True,
            })
        ```

        ### Protected Branch

        ```python
        import pulumi
        import pulumi_databricks as databricks

        production = databricks.PostgresBranch("production",
            branch_id="production",
            parent=this["name"],
            spec={
                "is_protected": True,
                "no_expiry": True,
            })
        ```

        ### Branch with Expiration (TTL)

        ```python
        import pulumi
        import pulumi_databricks as databricks

        temporary = databricks.PostgresBranch("temporary",
            branch_id="temp-feature-test",
            parent=this["name"],
            spec={
                "ttl": "604800s",
            })
        ```

        :param str resource_name: The name of the resource.
        :param PostgresBranchArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PostgresBranchArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 branch_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['PostgresBranchProviderConfigArgs', 'PostgresBranchProviderConfigArgsDict']]] = None,
                 spec: Optional[pulumi.Input[Union['PostgresBranchSpecArgs', 'PostgresBranchSpecArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PostgresBranchArgs.__new__(PostgresBranchArgs)

            if branch_id is None and not opts.urn:
                raise TypeError("Missing required property 'branch_id'")
            __props__.__dict__["branch_id"] = branch_id
            if parent is None and not opts.urn:
                raise TypeError("Missing required property 'parent'")
            __props__.__dict__["parent"] = parent
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["spec"] = spec
            __props__.__dict__["create_time"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["uid"] = None
            __props__.__dict__["update_time"] = None
        super(PostgresBranch, __self__).__init__(
            'databricks:index/postgresBranch:PostgresBranch',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            branch_id: Optional[pulumi.Input[_builtins.str]] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['PostgresBranchProviderConfigArgs', 'PostgresBranchProviderConfigArgsDict']]] = None,
            spec: Optional[pulumi.Input[Union['PostgresBranchSpecArgs', 'PostgresBranchSpecArgsDict']]] = None,
            status: Optional[pulumi.Input[Union['PostgresBranchStatusArgs', 'PostgresBranchStatusArgsDict']]] = None,
            uid: Optional[pulumi.Input[_builtins.str]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None) -> 'PostgresBranch':
        """
        Get an existing PostgresBranch resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] branch_id: The ID to use for the Branch. This becomes the final component of the branch's resource name.
               The ID is required and must be 1-63 characters long, start with a lowercase letter, and contain only lowercase letters, numbers, and hyphens.
               For example, `development` becomes `projects/my-app/branches/development`
        :param pulumi.Input[_builtins.str] create_time: (string) - A timestamp indicating when the branch was created
        :param pulumi.Input[_builtins.str] name: (string) - Output only. The full resource path of the branch.
               Format: projects/{project_id}/branches/{branch_id}
        :param pulumi.Input[_builtins.str] parent: The project containing this branch (API resource hierarchy).
               Format: projects/{project_id}
               
               Note: This field indicates where the branch exists in the resource hierarchy.
               For point-in-time branching from another branch, see `status.source_branch`
        :param pulumi.Input[Union['PostgresBranchProviderConfigArgs', 'PostgresBranchProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Union['PostgresBranchSpecArgs', 'PostgresBranchSpecArgsDict']] spec: The spec contains the branch configuration
        :param pulumi.Input[Union['PostgresBranchStatusArgs', 'PostgresBranchStatusArgsDict']] status: (BranchStatus) - The current status of a Branch
        :param pulumi.Input[_builtins.str] uid: (string) - System-generated unique ID for the branch
        :param pulumi.Input[_builtins.str] update_time: (string) - A timestamp indicating when the branch was last updated
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PostgresBranchState.__new__(_PostgresBranchState)

        __props__.__dict__["branch_id"] = branch_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["name"] = name
        __props__.__dict__["parent"] = parent
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["spec"] = spec
        __props__.__dict__["status"] = status
        __props__.__dict__["uid"] = uid
        __props__.__dict__["update_time"] = update_time
        return PostgresBranch(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="branchId")
    def branch_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID to use for the Branch. This becomes the final component of the branch's resource name.
        The ID is required and must be 1-63 characters long, start with a lowercase letter, and contain only lowercase letters, numbers, and hyphens.
        For example, `development` becomes `projects/my-app/branches/development`
        """
        return pulumi.get(self, "branch_id")

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - A timestamp indicating when the branch was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Output only. The full resource path of the branch.
        Format: projects/{project_id}/branches/{branch_id}
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Output[_builtins.str]:
        """
        The project containing this branch (API resource hierarchy).
        Format: projects/{project_id}

        Note: This field indicates where the branch exists in the resource hierarchy.
        For point-in-time branching from another branch, see `status.source_branch`
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.PostgresBranchProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def spec(self) -> pulumi.Output['outputs.PostgresBranchSpec']:
        """
        The spec contains the branch configuration
        """
        return pulumi.get(self, "spec")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output['outputs.PostgresBranchStatus']:
        """
        (BranchStatus) - The current status of a Branch
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def uid(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - System-generated unique ID for the branch
        """
        return pulumi.get(self, "uid")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - A timestamp indicating when the branch was last updated
        """
        return pulumi.get(self, "update_time")

